==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/AzureFirewallNetworkRuleCollectionResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Network rule collection resource.
 * @property action The action type of a rule collection.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within the Azure firewall. This name can be used to access the resource.
 * @property priority Priority of the network rule collection resource.
 * @property provisioningState The provisioning state of the network rule collection resource.
 * @property rules Collection of rules used by a network rule collection.
 */
public data class AzureFirewallNetworkRuleCollectionResponse(
    public val action: AzureFirewallRCActionResponse? = null,
    public val etag: String,
    public val id: String? = null,
    public val name: String? = null,
    public val priority: Int? = null,
    public val provisioningState: String,
    public val rules: List<AzureFirewallNetworkRuleResponse>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.AzureFirewallNetworkRuleCollectionResponse):
            AzureFirewallNetworkRuleCollectionResponse = AzureFirewallNetworkRuleCollectionResponse(
            action = javaType.action().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.network.kotlin.outputs.AzureFirewallRCActionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            etag = javaType.etag(),
            id = javaType.id().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            priority = javaType.priority().map({ args0 -> args0 }).orElse(null),
            provisioningState = javaType.provisioningState(),
            rules = javaType.rules().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.network.kotlin.outputs.AzureFirewallNetworkRuleResponse.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/AzureFirewallNetworkRuleCollectionResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Network rule collection resource.
 * @property action The action type of a rule collection.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within the Azure firewall. This name can be used to access the resource.
 * @property priority Priority of the network rule collection resource.
 * @property provisioningState The provisioning state of the network rule collection resource.
 * @property rules Collection of rules used by a network rule collection.
 */
public data class AzureFirewallNetworkRuleCollectionResponse(
    public val action: AzureFirewallRCActionResponse? = null,
    public val etag: String,
    public val id: String? = null,
    public val name: String? = null,
    public val priority: Int? = null,
    public val provisioningState: String,
    public val rules: List<AzureFirewallNetworkRuleResponse>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.AzureFirewallNetworkRuleCollectionResponse): AzureFirewallNetworkRuleCollectionResponse = AzureFirewallNetworkRuleCollectionResponse(
            action = javaType.action().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.network.kotlin.outputs.AzureFirewallRCActionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            etag = javaType.etag(),
            id = javaType.id().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            priority = javaType.priority().map({ args0 -> args0 }).orElse(null),
            provisioningState = javaType.provisioningState(),
            rules = javaType.rules().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.network.kotlin.outputs.AzureFirewallNetworkRuleResponse.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
